@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 use base 'Yote::Messenger';
 
@@ -23,6 +23,11 @@ sub is_root {
     return $self->get_login()->get__is_root();
 } #is_root
 
+sub is_master_root {
+    my $self = shift;
+    return $self->get_login()->get__is_master_root();    
+}
+
 1;
 
 __END__
@@ -52,6 +57,11 @@ This is called with a file uploaded POST where the file input name is 'avatar_fi
 
 Called to reveal if the login behind this account is a root login.
 
+=item is_master_root
+
+Returns trus if the account is the original root account
+
+
 =back
 
 =head1 AUTHOR
