@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use base 'Yote::Obj';
 
@@ -34,6 +34,11 @@ sub is_root {
     return $self->get__is_root();
 } #is_root
 
+sub is_master_root {
+    my $self = shift;
+    return $self->get__is_master_root();    
+}
+
 sub upload_avatar {
     my( $self, $data ) = @_;
     $self->set_avatar( $data->{avatar} );
@@ -65,6 +70,10 @@ container objects that store state data for the users.
 
 Returns trus if the account has root privileges.
 
+=item is_master_root
+
+Returns trus if the account is the original root account
+
 =item reset_password
 
 Resets the password for this login taking a hash reference as an argument with the keys 'op' for old password, 
