@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.051';
+$VERSION = '0.052';
 
 no warnings 'uninitialized';
 
@@ -101,6 +101,16 @@ sub create_login {
     die "no handle given";
 
 } #create_login
+
+# returns cron object for root
+sub cron {
+    my( $self, $data, $acct ) = @_;
+    if( $acct->is_root() ) {
+	return $self->get__crond();
+    }
+    die "Permissions Error";
+} #cron
+
 #
 # Fetches objects by id list
 #
@@ -158,11 +168,6 @@ sub guest_token {
     return $token;
 } #guest_token
 
-sub is_root {
-    my( $self, $check_account, $acct ) = @_;
-    return $self->get__roots({})->{ Yote::ObjProvider::get_id( $check_account ) };
-} #is_root
-
 #
 # Validates that the given credentials are given
 #   (client side) use : login({h:'handle',p:'password'});
@@ -324,16 +329,41 @@ sub _check_root {
     unless( $root_login ) {
 	$root_login = new Yote::Login();
 	$root_login->set_handle( $root_name );
-	$root_login->set__is_root( 1 );
+	$root_login->set__is_master_root( 1 );
 
         $root_login->set__time_created( time() );
 
 	$self->_hash_insert( '_handles', $lc_handle, $root_login );	
     }
+    $root_login->set__is_root( 1 );
+    $root_login->set__is_master_root( 1 );
 
     $root_login->set__password( $encr_passwd );
-    
-} #_create_root
+
+    return $root_login;
+} #_check_root
+
+#
+# Transforms the login into a login with root privs. Do not use lightly.
+#
+sub make_root {
+    my( $self, $login, $acct ) = @_;
+    die "Access Error" unless $acct->is_root();
+    $login->set__is_root( 1 );
+    return;
+} #make_root
+
+#
+# Removes root privs from a login. Do not use lightly. Does not remove the last root if there is one
+#
+sub remove_root {
+    my( $self, $login, $acct ) = @_;
+    die "Access Error" unless $acct->is_root();
+    die "Cannot remove master root account" if $login->get__is_master_root();
+    $login->set__is_root( 0 );
+    return;
+} #remove_root
+
 
 #
 # Create token and store with the account and return it.
@@ -392,7 +422,9 @@ the login token and the login object.
 
 Invalidates the tokens of the currently logged in user.
 
-=item new 
+=item make_root
+
+Takes a login as an argument and makes it root. Throws access error if the callee is not root.
 
 =item init - takes a hash of args, passing them to a new Yote::SQLite object and starting it up.
 
@@ -413,12 +445,20 @@ Returns the url_the_person_requested_recovery that was given in the recover_pass
 
 Purges the login account from the system if its credentials are verified. It moves the account to a special removed logins hidden field under the yote root.
 
+=item remove_root( login )
+
+Removes the root bit from the login.
+
 =item create_login( args )
 
 Create a login with the given client supplied args : h => handle, e => email, p => password.
 This checks to make sure handle and email address are not already taken. 
 This is invoked by the javascript call $.yote.create_login( handle, password, email )
 
+=item cron
+
+Returns the cron. Only a root login may call this.
+
 =back
 
 =head1 AUTHOR
